@@ -39,43 +39,6 @@
 
 #define GRADIENT_BAND_SIZE 4
 
-/**
- * eel_fill_rectangle:
- * @drawable: Target to draw into.
- * @gc: Graphics context (mainly for clip).
- * @rectangle: Rectangle to fill.
- *
- * Fill the rectangle with the foreground color.
- * Convenient when you have a GdkRectangle structure.
- */
-void
-eel_fill_rectangle (GdkDrawable *drawable,
-		    GdkGC *gc,
-		    const GdkRectangle *rectangle)
-{
-	gdk_draw_rectangle (drawable, gc, TRUE,
-			    rectangle->x, rectangle->y,
-			    rectangle->width, rectangle->height);
-}
-
-/**
- * eel_rectangle_contains:
- * @rectangle: Rectangle possibly containing a point.
- * @x: X coordinate of a point.
- * @y: Y coordinate of a point.
- *
- * Retun TRUE if point is contained inside a rectangle
- */
-gboolean
-eel_rectangle_contains (const GdkRectangle *rectangle, 
-			     int x, 
-			     int y)
-{
-	g_return_val_if_fail (rectangle != NULL, FALSE);
-	return rectangle->x <= x && rectangle->x + rectangle->width >= x
-		&& rectangle->y <= y && rectangle->y + rectangle->height >= y;
-}
-
 /**
  * eel_gdk_rectangle_contains_rectangle:
  * @outer: Rectangle possibly containing another rectangle.
@@ -90,29 +53,6 @@ eel_gdk_rectangle_contains_rectangle (GdkRectangle outer, GdkRectangle inner)
 		&& outer.y <= inner.y && outer.y + outer.height >= inner.y + inner.height;
 }
 
-/**
- * eel_rectangle_inset:
- * @rectangle: Rectangle we are insetting.
- * @x: Horizontal ammount to inset by.
- * @y: Vertical ammount to inset by.
- *
- * Inset a rectangle by a given horizontal and vertical ammount.
- * Pass in negative inset values to grow the rectangle, positive to
- * shrink it.
- */
-void
-eel_rectangle_inset (GdkRectangle *rectangle, 
-		     int x, 
-		     int y)
-{
-	g_return_if_fail (rectangle != NULL);
-
-	rectangle->x += x;
-	rectangle->width -= 2 * x;
-	rectangle->y += y;
-	rectangle->height -= 2 * y;
-}
-
 /**
  * eel_interpolate_color:
  * @ratio: Place on line between colors to interpolate.
@@ -155,8 +95,6 @@ eel_gradient_new (const char *start_color,
 		       const char *end_color,
 		       gboolean is_horizontal)
 {
-	g_return_val_if_fail (is_horizontal == FALSE || is_horizontal == TRUE, NULL);
-
 	/* Handle the special case where the start and end colors are identical.
 	   Handle the special case where the end color is an empty string.
 	*/
@@ -308,7 +246,7 @@ eel_gradient_set_edge_color (const char *gradient_spec,
 	char *opposite_color;
 	char *result;
 
-	g_return_val_if_fail (edge_color != NULL, g_strdup (gradient_spec));
+	g_assert (edge_color != NULL);
 
 	/* Get the color from the existing gradient spec. for the opposite
 	   edge. This will parse away all the stuff we don't want from the
@@ -342,6 +280,9 @@ char *
 eel_gradient_set_left_color_spec (const char *gradient_spec,
 				       const char *left_color)
 {
+	g_return_val_if_fail (gradient_spec != NULL, NULL);
+	g_return_val_if_fail (left_color != NULL, NULL);
+
 	return eel_gradient_set_edge_color (gradient_spec, left_color, TRUE, FALSE);
 }
 
@@ -357,6 +298,9 @@ char *
 eel_gradient_set_top_color_spec (const char *gradient_spec,
 				      const char *top_color)
 {
+	g_return_val_if_fail (gradient_spec != NULL, NULL);
+	g_return_val_if_fail (top_color != NULL, NULL);
+
 	return eel_gradient_set_edge_color (gradient_spec, top_color, FALSE, FALSE);
 }
 
@@ -372,6 +316,9 @@ char *
 eel_gradient_set_right_color_spec (const char *gradient_spec,
 					const char *right_color)
 {
+	g_return_val_if_fail (gradient_spec != NULL, NULL);
+	g_return_val_if_fail (right_color != NULL, NULL);
+
 	return eel_gradient_set_edge_color (gradient_spec, right_color, TRUE, TRUE);
 }
 
@@ -387,16 +334,19 @@ char *
 eel_gradient_set_bottom_color_spec (const char *gradient_spec,
 					 const char *bottom_color)
 {
+	g_return_val_if_fail (gradient_spec != NULL, NULL);
+	g_return_val_if_fail (bottom_color != NULL, NULL);
+
 	return eel_gradient_set_edge_color (gradient_spec, bottom_color, FALSE, TRUE);
 }
 
 /**
  * eel_gdk_color_parse_with_white_default
- * @color_spec: A color spec.
+ * @color_spec: A color spec, or NULL.
  * @color: Pointer to place to put resulting color.
  *
  * The same as gdk_color_parse, except sets the color to white if
- * the spec. can't be parsed instead of returning a boolean flag.
+ * the spec. can't be parsed, instead of returning a boolean flag.
  */
 void
 eel_gdk_color_parse_with_white_default (const char *color_spec,
@@ -404,6 +354,8 @@ eel_gdk_color_parse_with_white_default (const char *color_spec,
 {
 	gboolean got_color;
 
+	g_return_if_fail (color != NULL);
+
 	got_color = FALSE;
 	if (color_spec != NULL) {
 		if (eel_gdk_color_parse (color_spec, color)) {
@@ -420,7 +372,7 @@ eel_gdk_color_parse_with_white_default (const char *color_spec,
 
 /**
  * eel_parse_rgb_with_white_default
- * @color_spec: A color spec.
+ * @color_spec: A color spec, or NULL.
  * Returns: An rgb value.
  *
  * The same as gdk_color_parse, except sets the color to white if
